@@ -11,6 +11,7 @@
 
 import datetime
 import os
+import requests
 
 import numpy as np
 import pandas
@@ -139,11 +140,6 @@ def get_data(state=None, climate_division=None, start=None, end=None,
         if climate_division:
             year_data = year_data[year_data['climate_division'] == climate_division]
 
-        if start_year == year:
-            year_data = year_data[year_data['week'] >= start_week]
-        if end_year == year:
-            year_data = year_data[year_data['week'] <= end_week]
-
         year_data = _reindex_data(year_data)
 
         if data is None:
@@ -151,7 +147,14 @@ def get_data(state=None, climate_division=None, start=None, end=None,
         else:
             # some data are duplicated (e.g. final data from 2011 stretches into
             # prelim data of 2012), so just take those that are new
-            data = data.append(year_data.ix[year_data.index - data.index])
+            append_index = year_data.index - data.index
+            if len(append_index):
+                data = data.append(year_data.ix[append_index])
+
+    # restrict results to date range
+    period_index = pandas.PeriodIndex(data['period'])
+    periods_in_range = (period_index >= start_date) & (period_index <= end_date)
+    data = data[periods_in_range]
 
     # this does what data.reset_index() should do, but at least as of 0.10.1, that sets
     # will cast period objects to ints
@@ -193,7 +196,7 @@ def _convert_state_codes(dataframe):
 
 
 def _convert_week_numbers(dataframe):
-    """adds state abbreviations to a dataframe, based on state codes"""
+    """convert a dataframe's week numbers to period objects"""
     weeks = [key for key, group in dataframe.groupby(['year', 'week'])]
     periods = [(week[0], week[1], _period_for_week(*week)) for week in weeks]
     period_dataframe = pandas.DataFrame(periods, columns=['year', 'week', 'period'])
@@ -220,21 +223,29 @@ def _first_sunday(year):
 
 
 def _get_data_format(year):
-    if year >= 1997:
+    if year >= 2001:
         return 'format5'
-    elif 1988 <= year <= 1996:
-        return 'format2'
+    elif 1997 <= year <= 2000:
+        return 'format4'
     else:
-        return 'unknown'
+        return 'format2'
 
 
 def _get_data_url(year):
     current_year, current_week = _week_number(datetime.date.today())
     if year == current_year:
         return 'http://ftp.cpc.ncep.noaa.gov/htdocs/temp4/current.data'
-    elif year == 2011:
-        return 'http://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer11-PRELIM'
-    elif 1985 < year <= 2010:
+    elif year == current_year - 1:
+        url = 'http://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer%s-PRELIM' % str(year)[-2:]
+        if not _url_exists(url):
+            url = 'http://ftp.cpc.ncep.noaa.gov/htdocs/temp4/current.data'
+        return url
+    elif year == current_year - 2:
+        url = 'http://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer%s' % str(year)[-2:]
+        if not _url_exists(url):
+            url = 'http://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer%s-PRELIM' % str(year)[-2:]
+        return url
+    elif 1985 < year < current_year - 2:
         return 'http://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer%s' % str(year)[-2:]
     elif year <= 1985:
         return 'http://ftp.cpc.ncep.noaa.gov/htdocs/temp2/palmer73-85'
@@ -248,27 +259,43 @@ def _open_data_file(url):
 
 
 def _parse_data_file(data_file, palmer_format):
+    """
+    based on the fortran format strings:
+        format2: FORMAT(I4,3I2,F4.1,F4.0,10F6.2,4F6.4,F6.3,10F6.2,F4.0,12F6.2)
+        format4: FORMAT(2I4,I2,F4.1,F4.0,10F6.2,4F6.4,F6.3,10F6.2,F4.0,12F6.2)
+        format5: FORMAT(2I4,I2,F5.2,F5.1,10F6.2,4F6.4,F6.3,10F6.2,F4.0,12F6.2)
+    """
+    to_yyyy = 0
     if palmer_format == 'format5':
-        delim_sequence = (2, 2, 4, 2, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 4, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6)
+        delim_sequence = (2, 2, 4, 2, 5, 5) + 10*(6,) + 4*(6,) + (6,) + 10*(6,) + (4,) + 12*(6,)
         use_columns = (0, 1, 2, 3, 4, 5, 9, 15, 28, 29, 37, 40, 41)
-        dtype = [
-            ('state_code', 'i1'),
-            ('climate_division', 'i1'),
-            ('year', 'i4'),
-            ('week', 'i4'),
-            ('precipitation', 'f8'),
-            ('temperature', 'f8'),
-            ('potential_evap', 'f8'),
-            ('runoff', 'f8'),
-            ('soil_moisture_upper', 'f8'),
-            ('soil_moisture_lower', 'f8'),
-            ('pdsi', 'f8'),
-            ('cmi', 'f8')
-        ]
+    elif palmer_format == 'format4':
+        delim_sequence = (2, 2, 4, 2, 4, 4) + 10*(6,) + 4*(6,) + (6,) + 10*(6,) + (4,) + 12*(6,)
+        use_columns = (0, 1, 2, 3, 4, 5, 9, 15, 28, 29, 37, 40, 41)
+    elif palmer_format == 'format2':
+        delim_sequence = (2, 2, 2, 2, 2, 4, 4) + 10*(6,) + 4*(6,) + (6,) + 10*(6,) + (4,) + 12*(6,)
+        use_columns = (0, 1, 2, 3, 5, 6, 10, 16, 29, 30, 38, 41, 42)
+        to_yyyy = 1900
     else:
         raise NotImplementedError("we have not implemented the format for given date range")
 
+    dtype = [
+        ('state_code', 'i1'),
+        ('climate_division', 'i1'),
+        ('year', 'i4'),
+        ('week', 'i4'),
+        ('precipitation', 'f8'),
+        ('temperature', 'f8'),
+        ('potential_evap', 'f8'),
+        ('runoff', 'f8'),
+        ('soil_moisture_upper', 'f8'),
+        ('soil_moisture_lower', 'f8'),
+        ('pdsi', 'f8'),
+        ('cmi', 'f8')
+    ]
+
     data_array = np.genfromtxt(data_file, dtype=dtype, delimiter=delim_sequence, usecols=use_columns)
+    data_array['year'] += to_yyyy
     dataframe = pandas.DataFrame(data_array)
     return dataframe
 
@@ -290,6 +317,10 @@ def _reindex_data(dataframe):
             drop=False)
 
 
+def _url_exists(url):
+    return requests.head(url).status_code == 200
+
+
 def _value_dict(value):
     value_dict = value.to_dict()
     value_dict['period'] = str(value_dict['period'])
